@@ -11,9 +11,13 @@ def main():
         db=MongoClient(config("MONGODB_URI")).get_default_database(),
         cboe_collection_name=config("CBOE_COLLECTION_NAME"),
         spot_collection_name=config("SPOT_COLLECTION_NAME"),
-        open_interest_collection_name=config("OPEN_INTEREST_COLLECTION_NAME"),
     )
-    query_manager.open_interest.insert(now)
+    query_manager.spot_queries.insert_many(
+        document={
+            "current_price": current_price
+        },
+        now = now
+    )
     print("success")
 
 
